@@ -876,6 +876,8 @@ _gnome_vfs_get_unix_mount_table (GList **return_list)
 #endif
 
 	stat_file = get_fstab_file ();
+
+	*return_list = NULL;
  
     	if (stat (stat_file, &fsb) < 0) {
 	    	g_warning ("Unable to stat %s: %s", stat_file,
@@ -906,6 +908,14 @@ _gnome_vfs_get_unix_mount_table (GList **return_list)
 		mib[1] = VFS_USERMOUNT;
 		sysctl (mib, 2, &usermnt, &len, NULL, 0);
 	}
+#elif defined(CTL_KERN) && defined(KERN_USERMOUNT)
+	{
+		int mib[2];
+
+		mib[0] = CTL_KERN;
+		mib[1] = KERN_USERMOUNT;
+		sysctl (mib, 2, &usermnt, &len, NULL, 0);
+	}
 #endif
 #endif
 
@@ -1083,7 +1093,7 @@ _gnome_vfs_unix_mount_point_free (GnomeVFSUnixMountPoint *mount_point)
 }
 
 
-static gboolean
+static int
 strcmp_null (const char *str1,
 	     const char *str2)
 {
