@@ -671,7 +671,7 @@ _xdg_mime_magic_lookup_data (XdgMimeMagic *mime_magic,
       if (_xdg_mime_magic_match_compare_to_data (match, data, len))
 	{
 	  if (!had_match || match->priority > priority ||
-	      (mime_type != NULL && xdg_mime_mime_type_subclass (match->mime_type, mime_type)))
+	      (mime_type != NULL && _xdg_mime_mime_type_subclass (match->mime_type, mime_type)))
 	    {
 	      mime_type = match->mime_type;
 	      priority = match->priority;
@@ -688,7 +688,7 @@ _xdg_mime_magic_lookup_data (XdgMimeMagic *mime_magic,
 	  for (n = 0; n < n_mime_types; n++)
 	    {
 	      if (mime_types[n] && 
-		  xdg_mime_mime_type_equal (mime_types[n], match->mime_type))
+		  _xdg_mime_mime_type_equal (mime_types[n], match->mime_type))
 		mime_types[n] = NULL;
 	    }
 	}
